import { PointerEventHandler } from 'react';
declare type Callback = (e: PointerEvent) => void;
/**
 * A hook that fires a callback when a click (pointerdown) was registered outside
 * of a component. Outside is defined as outside of your react tree, which means
 * that this works with portals.
 *
 * Examples:
 *
 * ```tsx
 * const OutsideTest = () => {
 *   const handler = useClickOutside(e => {
 *     console.log('Outside')
 *   })
 *
 *   return (
 *     <div onPointerDown={handler}>
 *       <span>Clicks here is inside</span>
 *       {ReactDOM.createPortal(
 *         <span>Clicks here are also inside</span>,
 *         portalContainer
 *       )}
 *     </div>
 *   )
 * }
 * ```
 */
export declare const useClickOutside: (callback: Callback) => PointerEventHandler;
export {};
